import React, { useEffect } from 'react';
import { Box, Typography, styled, useTheme } from '@mui/material';
import BrainIcon from '@mui/icons-material/Psychology';

const Dot = styled('span')`
  display: inline-block;
  width: 4px;
  height: 4px;
  border-radius: 50%;
  background-color: currentColor;
  opacity: 0.4;
  margin: 0 2px;
  animation: dotAnimation 1.5s ease-in-out infinite;

  &:nth-child(1) {
    animation-delay: 0s;
  }
  &:nth-child(2) {
    animation-delay: 0.2s;
  }
  &:nth-child(3) {
    animation-delay: 0.4s;
  }
`;

const DotAnimationContainer = styled('span')`
  display: inline-block;
`;

const ThinkingIndicator = () => {
  const theme = useTheme();

  useEffect(() => {
    const style = document.createElement('style');
    style.appendChild(document.createTextNode(styledKeyframes));
    document.head.appendChild(style);

    return () => {
      document.head.removeChild(style);
    };
  }, [theme]);

  return (
    <Box sx={{ display: 'flex', alignItems: 'center', gap: 1, color: 'text.secondary' }}>
      <BrainIcon />
      <Typography variant="body2">
        Thinking
        <DotAnimationContainer>
          <Dot />
          <Dot />
          <Dot />
        </DotAnimationContainer>
      </Typography>
    </Box>
  );
};

const styledKeyframes = `
@keyframes dotAnimation {
  0% {
    opacity: 0.4;
  }
  50% {
    opacity: 1;
  }
  100% {
    opacity: 0.4;
  }
}
`;

export default ThinkingIndicator;
